/**
 * \file        lzma/auto.h
 * \brief       Decoder with automatic file format detection
 *
 * \author      Copyright (C) 1999-2006 Igor Pavlov
 * \author      Copyright (C) 2007 Lasse Collin
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 */

#ifndef LZMAALPHA_H_INTERNAL
#	error Never include this file directly. Use <lzma.h> instead.
#endif


/**
 * \brief       Decode .lzma Streams and LZMA_Alone files with autodetection
 *
 * Autodetects between the .lzma Stream and LZMA_Alone formats, and
 * calls lzmaalpha_stream_decoder_init() or lzmaalpha_alone_decoder_init() once
 * the type of the file has been detected.
 *
 * \param       strm        Pointer to propertily prepared lzmaalpha_stream
 * \param       header      Pointer to hold a pointer to Extra Records read
 *                          from the Header Metadata Block. Use NULL if
 *                          you don't care about Extra Records.
 * \param       footer      Same as header, but for Footer Metadata Block.
 *
 * \return      - LZMAALPHA_OK: Initialization was successful.
 *              - LZMAALPHA_MEM_ERROR: Cannot allocate memory.
 */
extern lzmaalpha_ret lzmaalpha_auto_decoder(lzmaalpha_stream *strm,
		lzmaalpha_extra **header, lzmaalpha_extra **footer);
